package io.hmit.modules.appointment.controller;

import io.hmit.common.annotation.LogOperation;
import io.hmit.common.constant.Constant;
import io.hmit.common.page.PageData;
import io.hmit.common.utils.ExcelUtils;
import io.hmit.common.utils.Result;
import io.hmit.common.validator.AssertUtils;
import io.hmit.common.validator.ValidatorUtils;
import io.hmit.common.validator.group.AddGroup;
import io.hmit.common.validator.group.DefaultGroup;
import io.hmit.common.validator.group.UpdateGroup;
import io.hmit.modules.appointment.dto.AppointmentOrderServiceDTO;
import io.hmit.modules.appointment.excel.AppointmentOrderServiceExcel;
import io.hmit.modules.appointment.service.AppointmentOrderServiceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * 订单服务关联表
 *
 * @author zsh 408538940@qq.com
 * @since 1.0.0 2021-02-13
 */
@RestController
@RequestMapping("appointment/appointmentorderservice")
@Api(tags="订单服务关联表")
public class AppointmentOrderServiceController {
    @Autowired
    private AppointmentOrderServiceService appointmentOrderServiceService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String")
    })
    @RequiresPermissions("appointment:appointmentorderservice:page")
    public Result<PageData<AppointmentOrderServiceDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<AppointmentOrderServiceDTO> page = appointmentOrderServiceService.page(params);

        return new Result<PageData<AppointmentOrderServiceDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    @RequiresPermissions("appointment:appointmentorderservice:info")
    public Result<AppointmentOrderServiceDTO> get(@PathVariable("id") Long id){
        AppointmentOrderServiceDTO data = appointmentOrderServiceService.get(id);

        return new Result<AppointmentOrderServiceDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    @LogOperation("保存")
    @RequiresPermissions("appointment:appointmentorderservice:save")
    public Result save(@RequestBody AppointmentOrderServiceDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        appointmentOrderServiceService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    @LogOperation("修改")
    @RequiresPermissions("appointment:appointmentorderservice:update")
    public Result update(@RequestBody AppointmentOrderServiceDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        appointmentOrderServiceService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    @LogOperation("删除")
    @RequiresPermissions("appointment:appointmentorderservice:delete")
    public Result delete(@RequestBody Long[] ids){
        //校验数据
        AssertUtils.isArrayEmpty(ids, "id");

        appointmentOrderServiceService.delete(ids);

        return new Result();
    }

    @GetMapping("export")
    @ApiOperation("导出")
    @LogOperation("导出")
    @RequiresPermissions("appointment:appointmentorderservice:export")
    public void export(@ApiIgnore @RequestParam Map<String, Object> params, HttpServletResponse response) throws Exception {
        List<AppointmentOrderServiceDTO> list = appointmentOrderServiceService.list(params);

        ExcelUtils.exportExcelToTarget(response, null, list, AppointmentOrderServiceExcel.class);
    }

}