package io.hmit.modules.appointment.controller;

import io.hmit.common.annotation.LogOperation;
import io.hmit.common.constant.Constant;
import io.hmit.common.page.PageData;
import io.hmit.common.utils.ExcelUtils;
import io.hmit.common.utils.Result;
import io.hmit.common.validator.AssertUtils;
import io.hmit.common.validator.ValidatorUtils;
import io.hmit.common.validator.group.AddGroup;
import io.hmit.common.validator.group.DefaultGroup;
import io.hmit.common.validator.group.UpdateGroup;
import io.hmit.modules.appointment.dto.AppointmentTimeManageDTO;
import io.hmit.modules.appointment.excel.AppointmentTimeManageExcel;
import io.hmit.modules.appointment.service.AppointmentTimeManageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Map;


/**
 * 预约时间管理
 *
 * @author zsh 408538940@qq.com
 * @since 1.0.0 2021-02-15
 */
@RestController
@RequestMapping("appointment/appointmenttimemanage")
@Api(tags="预约时间管理")
public class AppointmentTimeManageController {
    @Autowired
    private AppointmentTimeManageService appointmentTimeManageService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String")
    })
    @RequiresPermissions("appointment:appointmenttimemanage:page")
    public Result<PageData<AppointmentTimeManageDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<AppointmentTimeManageDTO> page = appointmentTimeManageService.page(params);

        return new Result<PageData<AppointmentTimeManageDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    @RequiresPermissions("appointment:appointmenttimemanage:info")
    public Result<AppointmentTimeManageDTO> get(@PathVariable("id") Long id){
        AppointmentTimeManageDTO data = appointmentTimeManageService.get(id);

        return new Result<AppointmentTimeManageDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    @LogOperation("保存")
    @RequiresPermissions("appointment:appointmenttimemanage:save")
    public Result save(@RequestBody AppointmentTimeManageDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        appointmentTimeManageService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    @LogOperation("修改")
    @RequiresPermissions("appointment:appointmenttimemanage:update")
    public Result update(@RequestBody AppointmentTimeManageDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        appointmentTimeManageService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    @LogOperation("删除")
    @RequiresPermissions("appointment:appointmenttimemanage:delete")
    public Result delete(@RequestBody Long[] ids){
        //校验数据
        AssertUtils.isArrayEmpty(ids, "id");

        appointmentTimeManageService.delete(ids);

        return new Result();
    }

    @GetMapping("export")
    @ApiOperation("导出")
    @LogOperation("导出")
    @RequiresPermissions("appointment:appointmenttimemanage:export")
    public void export(@ApiIgnore @RequestParam Map<String, Object> params, HttpServletResponse response) throws Exception {
        List<AppointmentTimeManageDTO> list = appointmentTimeManageService.list(params);

        ExcelUtils.exportExcelToTarget(response, null, list, AppointmentTimeManageExcel.class);
    }

}