package io.hmit.modules.appointment.controller;


import io.hmit.common.constant.Constant;
import io.hmit.common.page.PageData;
import io.hmit.common.utils.Result;
import io.hmit.common.validator.AssertUtils;
import io.hmit.common.validator.ValidatorUtils;
import io.hmit.common.validator.group.AddGroup;
import io.hmit.common.validator.group.DefaultGroup;
import io.hmit.common.validator.group.UpdateGroup;
import io.hmit.modules.appointment.dto.AppointmentServiceDTO;
import io.hmit.modules.appointment.service.AppointmentServiceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;


import java.util.Map;


/**
 * 可供预约的服务事项种类(不确定是否数据落地)。
 *
 * @author zsh 408538940@qq.com
 * @since 1.0.0 2021-02-13
 */
@RestController
@RequestMapping("app/appointmentservice")
@Api(tags="可供预约的服务事项种类(不确定是否数据落地)。")
public class AppointmentServiceController {
    @Autowired
    private AppointmentServiceService appointmentServiceService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.ORDER_FIELD, value = "排序字段", paramType = "query", dataType="String") ,
        @ApiImplicitParam(name = Constant.ORDER, value = "排序方式，可选值(asc、desc)", paramType = "query", dataType="String")
    })
    public Result<PageData<AppointmentServiceDTO>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<AppointmentServiceDTO> page = appointmentServiceService.page(params);

        return new Result<PageData<AppointmentServiceDTO>>().ok(page);
    }

    @GetMapping("{id}")
    @ApiOperation("信息")
    public Result<AppointmentServiceDTO> get(@PathVariable("id") Long id){
        AppointmentServiceDTO data = appointmentServiceService.get(id);

        return new Result<AppointmentServiceDTO>().ok(data);
    }

    @PostMapping
    @ApiOperation("保存")
    public Result save(@RequestBody AppointmentServiceDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        appointmentServiceService.save(dto);

        return new Result();
    }

    @PutMapping
    @ApiOperation("修改")
    public Result update(@RequestBody AppointmentServiceDTO dto){
        //校验数据
        ValidatorUtils.validateEntity(dto, UpdateGroup.class, DefaultGroup.class);

        appointmentServiceService.update(dto);

        return new Result();
    }

    @DeleteMapping
    @ApiOperation("删除")
    public Result delete(@RequestBody Long[] ids){
        //校验数据
        AssertUtils.isArrayEmpty(ids, "id");

        appointmentServiceService.delete(ids);

        return new Result();
    }
}
